
# Human Life Programming Language (HLPL)

HLPL is a programming language for human life. HLPL is composed from seven sofwtare:
> **Composer:** composes texts
> **templater:** templates texts 
> **transcriber:** transcribes texts
> **press:** designes web sites 
> **character:** simulates human life 
> **photographer:** simulates nature 
> **graphics:** makes graphics (movies, anime, games ...)
